@@ -327,12 +327,17 @@ as_node_get_attr_string (AsNodeData *data)
 
 	str = g_string_new ("");
 	for (l = data->attrs; l != NULL; l = l->next) {
+		g_autoptr(GString) value_safe = NULL;
 		attr = l->data;
 		if (g_strcmp0 (attr->key, "@comment") == 0 ||
 		    g_strcmp0 (attr->key, "@comment-tmp") == 0)
 			continue;
+		value_safe = g_string_new (attr->value);
+		as_utils_string_replace (value_safe, "&", "&amp;");
+		as_utils_string_replace (value_safe, "<", "&lt;");
+		as_utils_string_replace (value_safe, ">", "&gt;");
 		g_string_append_printf (str, " %s=\"%s\"",
-					attr->key, attr->value);
+					attr->key, value_safe->str);
 	}
 	return g_string_free (str, FALSE);
 }
@@ -783,22 +788,10 @@ as_node_passthrough_cb (GMarkupParseContext *context,
 	}
 }
 
-/**
- * as_node_from_xml: (skip)
- * @data: XML data
- * @flags: #AsNodeFromXmlFlags, e.g. %AS_NODE_FROM_XML_FLAG_NONE
- * @error: A #GError or %NULL
- *
- * Parses XML data into a DOM tree.
- *
- * Returns: (transfer none): A populated #AsNode tree
- *
- * Since: 0.1.0
- **/
-AsNode *
-as_node_from_xml (const gchar *data,
-		  AsNodeFromXmlFlags flags,
-		  GError **error)
+static AsNode *
+as_node_from_xml_internal (const gchar *data, gssize data_sz,
+			   AsNodeFromXmlFlags flags,
+			   GError **error)
 {
 	AsNodeToXmlHelper helper;
 	AsNode *root = NULL;
@@ -822,10 +815,7 @@ as_node_from_xml (const gchar *data,
 					  G_MARKUP_PREFIX_ERROR_POSITION,
 					  &helper,
 					  NULL);
-	ret = g_markup_parse_context_parse (ctx,
-					    data,
-					    -1,
-					    &error_local);
+	ret = g_markup_parse_context_parse (ctx, data, data_sz, &error_local);
 	if (!ret) {
 		g_set_error_literal (error,
 				     AS_NODE_ERROR,
@@ -847,6 +837,46 @@ as_node_from_xml (const gchar *data,
 	return root;
 }
 
+/**
+ * as_node_from_bytes: (skip)
+ * @bytes: a #GBytes
+ * @flags: #AsNodeFromXmlFlags, e.g. %AS_NODE_FROM_XML_FLAG_NONE
+ * @error: A #GError or %NULL
+ *
+ * Parses XML data into a DOM tree.
+ *
+ * Returns: (transfer none): A populated #AsNode tree
+ *
+ * Since: 0.7.6
+ **/
+AsNode *
+as_node_from_bytes (GBytes *bytes, AsNodeFromXmlFlags flags, GError **error)
+{
+	gsize sz = 0;
+	const gchar *buf;
+	g_return_val_if_fail (bytes != NULL, NULL);
+	buf = g_bytes_get_data (bytes, &sz);
+	return as_node_from_xml_internal (buf, (gssize) sz, flags, error);
+}
+
+/**
+ * as_node_from_xml: (skip)
+ * @data: XML data
+ * @flags: #AsNodeFromXmlFlags, e.g. %AS_NODE_FROM_XML_FLAG_NONE
+ * @error: A #GError or %NULL
+ *
+ * Parses XML data into a DOM tree.
+ *
+ * Returns: (transfer none): A populated #AsNode tree
+ *
+ * Since: 0.1.0
+ **/
+AsNode *
+as_node_from_xml (const gchar *data, AsNodeFromXmlFlags flags, GError **error)
+{
+	return as_node_from_xml_internal (data, -1, flags, error);
+}
+
 /**
  * as_node_to_file: (skip)
  * @root: A populated #AsNode tree
@@ -2207,7 +2237,7 @@ as_node_context_set_format_kind (AsNodeContext *ctx, AsFormatKind format_kind)
 /**
  * as_node_context_set_source_kind: (skip)
  * @ctx: a #AsNodeContext.
- * @format_kind: an API format kind, e.g. %AS_FORMAT_KIND_APPDATA
+ * @source_kind: an API format kind, e.g. %AS_FORMAT_KIND_APPDATA
  *
  * Sets the AppStream API format kind used when exporting nodes.
  *
