@@ -220,7 +220,7 @@ as_screenshot_get_images_for_locale (AsScreenshot *screenshot,
 /**
  * as_screenshot_get_image_for_locale:
  * @screenshot: a #AsScreenshot instance.
- * @locale: locale, or %NULL
+ * @locale: (nullable): locale, e.g. "en_GB"
  * @width: target width
  * @height: target height
  *
@@ -314,7 +314,7 @@ as_screenshot_get_source (AsScreenshot *screenshot)
 /**
  * as_screenshot_get_caption:
  * @screenshot: a #AsScreenshot instance.
- * @locale: the locale, or %NULL. e.g. "en_GB"
+ * @locale: (nullable): the locale, or %NULL. e.g. "en_GB"
  *
  * Gets the image caption for a specific locale.
  *
@@ -382,7 +382,7 @@ as_screenshot_add_image (AsScreenshot *screenshot, AsImage *image)
 /**
  * as_screenshot_set_caption:
  * @screenshot: a #AsScreenshot instance.
- * @locale: the locale, or %NULL. e.g. "en_GB"
+ * @locale: (nullable): the locale, or %NULL. e.g. "en_GB"
  * @caption: the caption text.
  *
  * Sets a caption on the screenshot for a specific locale.
@@ -436,15 +436,13 @@ as_screenshot_node_insert (AsScreenshot *screenshot,
 		as_node_add_attribute (n, "type",
 				       as_screenshot_kind_to_string (priv->kind));
 	}
-	if (as_node_context_get_version (ctx) >= 0.41) {
-		if (priv->captions != NULL) {
-			as_node_insert_localized (n,
-						  "caption",
-						  priv->captions,
-						  AS_NODE_INSERT_FLAG_DEDUPE_LANG);
-		}
+	if (priv->captions != NULL) {
+		as_node_insert_localized (n,
+					  "caption",
+					  priv->captions,
+					  AS_NODE_INSERT_FLAG_DEDUPE_LANG);
 	}
-	if (as_node_context_get_version (ctx) >= 0.8 && priv->priority != 0)
+	if (priv->priority != 0)
 		as_node_add_attribute_as_int (n, "priority", priv->priority);
 	for (i = 0; i < priv->images->len; i++) {
 		image = g_ptr_array_index (priv->images, i);
