@@ -24,6 +24,8 @@
 
 #include <glib-object.h>
 
+#include "as-ref-string.h"
+
 G_BEGIN_DECLS
 
 #define AS_TYPE_STEMMER	(as_stemmer_get_type ())
@@ -31,7 +33,7 @@ G_BEGIN_DECLS
 G_DECLARE_FINAL_TYPE (AsStemmer, as_stemmer, AS, STEMMER, GObject)
 
 AsStemmer	*as_stemmer_new			(void);
-const gchar	*as_stemmer_process		(AsStemmer	*stemmer,
+AsRefString	*as_stemmer_process		(AsStemmer	*stemmer,
 						 const gchar	*value);
 
 G_END_DECLS
