@@ -41,14 +41,17 @@ struct _AsStoreClass
 {
 	GObjectClass		parent_class;
 	void			(*changed)	(AsStore	*store);
+	void			(*app_added)	(AsStore	*store,
+						 AsApp		*app);
+	void			(*app_removed)	(AsStore	*store,
+						 AsApp		*app);
+	void			(*app_changed)	(AsStore	*store,
+						 AsApp		*app);
 	/*< private >*/
 	void (*_as_reserved1)	(void);
 	void (*_as_reserved2)	(void);
 	void (*_as_reserved3)	(void);
 	void (*_as_reserved4)	(void);
-	void (*_as_reserved5)	(void);
-	void (*_as_reserved6)	(void);
-	void (*_as_reserved7)	(void);
 };
 
 /**
@@ -63,20 +66,24 @@ struct _AsStoreClass
  * @AS_STORE_LOAD_FLAG_FLATPAK_USER:		Add flatpak user applications (obsolete)
  * @AS_STORE_LOAD_FLAG_FLATPAK_SYSTEM:		Add flatpak system applications (obsolete)
  * @AS_STORE_LOAD_FLAG_IGNORE_INVALID:		Ignore invalid files
+ * @AS_STORE_LOAD_FLAG_ONLY_UNCOMPRESSED:	Ignore compressed files
+ * @AS_STORE_LOAD_FLAG_ONLY_MERGE_APPS:		Ignore non-wildcard matches
  *
  * The flags to use when loading the store.
  **/
 typedef enum {
-	AS_STORE_LOAD_FLAG_NONE			= 0,	/* Since: 0.1.2 */
-	AS_STORE_LOAD_FLAG_APP_INFO_SYSTEM	= 1,	/* Since: 0.1.2 */
-	AS_STORE_LOAD_FLAG_APP_INFO_USER	= 2,	/* Since: 0.1.2 */
-	AS_STORE_LOAD_FLAG_APP_INSTALL		= 4,	/* Since: 0.1.2 */
-	AS_STORE_LOAD_FLAG_APPDATA		= 8,	/* Since: 0.2.2 */
-	AS_STORE_LOAD_FLAG_DESKTOP		= 16,	/* Since: 0.2.2 */
-	AS_STORE_LOAD_FLAG_ALLOW_VETO		= 32,	/* Since: 0.2.5 */
-	AS_STORE_LOAD_FLAG_FLATPAK_USER		= 64,	/* Since: 0.5.7 */
-	AS_STORE_LOAD_FLAG_FLATPAK_SYSTEM	= 128,	/* Since: 0.5.7 */
-	AS_STORE_LOAD_FLAG_IGNORE_INVALID	= 256,	/* Since: 0.5.8 */
+	AS_STORE_LOAD_FLAG_NONE			= 0,		/* Since: 0.1.2 */
+	AS_STORE_LOAD_FLAG_APP_INFO_SYSTEM	= 1 << 0,	/* Since: 0.1.2 */
+	AS_STORE_LOAD_FLAG_APP_INFO_USER	= 1 << 1,	/* Since: 0.1.2 */
+	AS_STORE_LOAD_FLAG_APP_INSTALL		= 1 << 2,	/* Since: 0.1.2 */
+	AS_STORE_LOAD_FLAG_APPDATA		= 1 << 3,	/* Since: 0.2.2 */
+	AS_STORE_LOAD_FLAG_DESKTOP		= 1 << 4,	/* Since: 0.2.2 */
+	AS_STORE_LOAD_FLAG_ALLOW_VETO		= 1 << 5,	/* Since: 0.2.5 */
+	AS_STORE_LOAD_FLAG_FLATPAK_USER		= 1 << 6,	/* Since: 0.5.7 */
+	AS_STORE_LOAD_FLAG_FLATPAK_SYSTEM	= 1 << 7,	/* Since: 0.5.7 */
+	AS_STORE_LOAD_FLAG_IGNORE_INVALID	= 1 << 8,	/* Since: 0.5.8 */
+	AS_STORE_LOAD_FLAG_ONLY_UNCOMPRESSED	= 1 << 9,	/* Since: 0.6.4 */
+	AS_STORE_LOAD_FLAG_ONLY_MERGE_APPS	= 1 << 10,	/* Since: 0.6.4 */
 	/*< private >*/
 	AS_STORE_LOAD_FLAG_LAST
 } AsStoreLoadFlags;
@@ -91,6 +98,7 @@ typedef enum {
  * @AS_STORE_ADD_FLAG_PREFER_LOCAL:			Local files will be used by default
  * @AS_STORE_ADD_FLAG_USE_UNIQUE_ID:			Allow multiple apps with the same AppStream ID
  * @AS_STORE_ADD_FLAG_USE_MERGE_HEURISTIC:		Use a heuristic when adding merge components
+ * @AS_STORE_ADD_FLAG_ONLY_NATIVE_LANGS:		Only load native languages
  *
  * The flags to use when adding applications to the store.
  **/
@@ -99,6 +107,7 @@ typedef enum {
 	AS_STORE_ADD_FLAG_PREFER_LOCAL		= 1 << 0,	/* Since: 0.2.2 */
 	AS_STORE_ADD_FLAG_USE_UNIQUE_ID		= 1 << 1,	/* Since: 0.6.1 */
 	AS_STORE_ADD_FLAG_USE_MERGE_HEURISTIC	= 1 << 2,	/* Since: 0.6.1 */
+	AS_STORE_ADD_FLAG_ONLY_NATIVE_LANGS	= 1 << 3,	/* Since: 0.6.5 */
 	/*< private >*/
 	AS_STORE_ADD_FLAG_LAST
 } AsStoreAddFlags;
@@ -168,17 +177,23 @@ gboolean	 as_store_from_xml		(AsStore	*store,
 						 const gchar	*icon_root,
 						 GError		**error);
 gboolean	 as_store_load			(AsStore	*store,
-						 AsStoreLoadFlags flags,
+						 guint32	 flags,
 						 GCancellable	*cancellable,
 						 GError		**error);
 gboolean	 as_store_load_path		(AsStore	*store,
 						 const gchar	*path,
 						 GCancellable	*cancellable,
 						 GError		**error);
+void		 as_store_load_search_cache	(AsStore	*store);
+void		 as_store_set_search_match	(AsStore	*store,
+						 guint16	 search_match);
+guint16		 as_store_get_search_match	(AsStore	*store);
 void		 as_store_remove_all		(AsStore	*store);
 GPtrArray	*as_store_get_apps		(AsStore	*store);
 GPtrArray	*as_store_get_apps_by_id	(AsStore	*store,
 						 const gchar	*id);
+GPtrArray	*as_store_get_apps_by_id_merge	(AsStore	*store,
+						 const gchar	*id);
 GPtrArray	*as_store_get_apps_by_metadata	(AsStore	*store,
 						 const gchar	*key,
 						 const gchar	*value);
@@ -186,7 +201,7 @@ AsApp		*as_store_get_app_by_id		(AsStore	*store,
 						 const gchar	*id);
 AsApp		*as_store_get_app_by_unique_id	(AsStore	*store,
 						 const gchar	*unique_id,
-						 AsStoreSearchFlags search_flags);
+						 guint32	 search_flags);
 AsApp		*as_store_get_app_by_id_ignore_prefix
 						(AsStore	*store,
 						 const gchar	*id);
@@ -199,18 +214,23 @@ AsApp		*as_store_get_app_by_pkgnames	(AsStore	*store,
 AsApp		*as_store_get_app_by_provide	(AsStore	*store,
 						 AsProvideKind	 kind,
 						 const gchar	*value);
+GPtrArray	*as_store_get_apps_by_provide	(AsStore	*store,
+						 AsProvideKind	 kind,
+						 const gchar	*value);
 void		 as_store_add_app		(AsStore	*store,
 						 AsApp		*app);
+void		 as_store_add_apps		(AsStore	*store,
+						 GPtrArray	*apps);
 void		 as_store_remove_app		(AsStore	*store,
 						 AsApp		*app);
 void		 as_store_remove_app_by_id	(AsStore	*store,
 						 const gchar	*id);
 void		 as_store_remove_apps_with_veto	(AsStore	*store);
 GString		*as_store_to_xml		(AsStore	*store,
-						 AsNodeToXmlFlags flags);
+						 guint32	 flags);
 gboolean	 as_store_to_file		(AsStore	*store,
 						 GFile		*file,
-						 AsNodeToXmlFlags flags,
+						 guint32	 flags,
 						 GCancellable	*cancellable,
 						 GError		**error);
 gboolean	 as_store_convert_icons		(AsStore	*store,
@@ -228,14 +248,14 @@ void		 as_store_set_destdir		(AsStore	*store,
 gdouble		 as_store_get_api_version	(AsStore	*store);
 void		 as_store_set_api_version	(AsStore	*store,
 						 gdouble	 api_version);
-AsStoreAddFlags	 as_store_get_add_flags		(AsStore	*store);
+guint32		 as_store_get_add_flags		(AsStore	*store);
 void		 as_store_set_add_flags		(AsStore	*store,
-						 AsStoreAddFlags add_flags);
-AsStoreWatchFlags as_store_get_watch_flags	(AsStore	*store);
+						 guint32	 add_flags);
+guint32		 as_store_get_watch_flags	(AsStore	*store);
 void		 as_store_set_watch_flags	(AsStore	*store,
-						 AsStoreWatchFlags watch_flags);
+						 guint32	 watch_flags);
 GPtrArray	*as_store_validate		(AsStore	*store,
-						 AsAppValidateFlags flags,
+						 guint32	 flags,
 						 GError		**error);
 void		 as_store_add_metadata_index	(AsStore	*store,
 						 const gchar	*key);
