@@ -83,12 +83,14 @@ typedef enum {
  * AsVersionParseFlag:
  * @AS_VERSION_PARSE_FLAG_NONE:			No flags set
  * @AS_VERSION_PARSE_FLAG_USE_TRIPLET:		Use Microsoft-style version numbers
+ * @AS_VERSION_PARSE_FLAG_USE_BCD:		Use binary coded decimal notation
  *
  * The flags used when parsing version numbers.
  **/
 typedef enum {
 	AS_VERSION_PARSE_FLAG_NONE		= 0,
 	AS_VERSION_PARSE_FLAG_USE_TRIPLET	= 1 << 0,
+	AS_VERSION_PARSE_FLAG_USE_BCD		= 1 << 1,	/* Since: 0.7.3 */
 	/*< private >*/
 	AS_VERSION_PARSE_FLAG_LAST
 } AsVersionParseFlag;
@@ -124,6 +126,10 @@ gint		 as_utils_vercmp		(const gchar	*version_a,
 						 const gchar	*version_b);
 gboolean	 as_utils_guid_is_valid		(const gchar	*guid);
 gchar		*as_utils_guid_from_string	(const gchar	*str);
+gchar		*as_utils_guid_from_data	(const gchar	*namespace_id,
+						 const guint8	*data,
+						 gsize		 data_len,
+						 GError		**error);
 gchar		*as_utils_version_from_uint32	(guint32	 val,
 						 AsVersionParseFlag flags);
 gchar		*as_utils_version_from_uint16	(guint16	 val,
